Documentation
¶
Overview ¶
This is the filter_on_field plugin. It contains the code that implements the Traefik interfaces, and filters requests based on the parameters passed in the configuration, allowing all values except those that match the disallowed content.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type Config ¶
type Config struct {
// contains filtered or unexported fields
}
A configuration struct for the filter. This is populated from the Traefik configuration, regardless of whether it's used via the dynamic configuration or the static configuration.
type Error ¶
type Error struct {
// contains filtered or unexported fields
}
An error type that can be returned by the filter
type FilterOnField ¶
type FilterOnField struct {
// contains filtered or unexported fields
}
The Filter On Field Struct that implements all of the Traefik interfaces in order to be used as a Traefik middleware plugin.
func (*FilterOnField) ServeHTTP ¶
func (f *FilterOnField) ServeHTTP(rw http.ResponseWriter, req *http.Request)
The ServeHTTP method is called by Traefik when a request is received. It takes a response writer and a request. When the checks pass, it calls the next handler in the chain. When the checks fail, it returns an error response.